@@ -11,7 +11,7 @@ from upgrade_knausj.handle_challenging_commit import (
     handle_challenging_commit,
 )
 from upgrade_knausj.setup import setup_knausj, setup_mine
-from upgrade_knausj.util import error_and_exit
+from upgrade_knausj.util import error_and_exit, print_slack_help_info
 
 app = typer.Typer()
 
@@ -33,9 +33,12 @@ def main():
     """
 
     repo_base_path.mkdir(parents=True, exist_ok=True)
-    log_path = repo_base_path / "log.txt"
+    log_dir = repo_base_path / "logs"
+    log_dir.mkdir(parents=True, exist_ok=True)
     repo_path = repo_base_path / "knausj_staging"
 
+    print("[bold green]Welcome to the upgrade-knausj script![/bold green] :wave:\n")
+    print_slack_help_info("you run into any issues", True)
     print(f"Working in '{repo_path}'...\n")
     repo = Repo.init(repo_path)
 
@@ -50,7 +53,7 @@ def main():
     mine_main.checkout(True)
 
     for challenging_commit in challenging_commits:
-        handle_challenging_commit(repo, log_path, challenging_commit, mine_main)
+        handle_challenging_commit(repo, log_dir, challenging_commit, mine_main)
 
     if not repo.is_ancestor(knausj_main.commit, repo.head.commit):
         print("Merging with 'knausj_main'...")
@@ -65,4 +68,6 @@ def main():
     if Confirm.ask(
         ":tada: [bold green]All done![/bold green] :tada:  Shall I push to your repo?"
     ):
-        repo.git.push()
+        repo.git.push(
+            mine_remote_main.remote_name, f"HEAD:{mine_remote_main.remote_head}"
+        )
